# django-utils-lds

**djlds** Django 相关的模块，我们会把 ilds 里面和 Django 相关的功能，移动到这里来。

查看 [更改日志](https://github.com/ldsxp/django-utils-lds/blob/master/CHANGELOG.md)

## 安装：
```shell
pip install -U djlds
```


## 简单的例子:

```python
...
```

